@@ -122,12 +122,27 @@ if not options.nocli:
 	install ('build/bin/birdfont-export', '/bin', 755)
 	install ('build/bin/birdfont-import', '/bin', 755)
 
+def is_debian():
+  try:
+  	version = platform.version()
+  	print("OS Version: " + version)
+  	
+  	if version.find("Ubuntu") > -1:
+  		return True
+
+  	if version.find("Debian") > -1:
+  		return True
+  		
+  except:
+    return False
+    
+  return False
+    
 #library
 if sys.platform == 'darwin':
 	libdir = '/lib'
 elif not options.libdir:
-	
-	if platform.dist()[0] == 'Ubuntu' or platform.dist()[0] == 'Debian':
+	if is_debian():
 		process = subprocess.Popen(['dpkg-architecture', '-qDEB_HOST_MULTIARCH'], stdout=subprocess.PIPE)
 		out, err = process.communicate()
 		out = out.decode('ascii')
